# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hzdata.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='hzdata.proto',
  package='pb',
  syntax='proto3',
  serialized_options=b'Z\004.;pb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0chzdata.proto\x12\x02pb\"3\n\rHZDataRequest\x12\x12\n\nmethodName\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\x0c\"@\n\x0eHZDataResponse\x12\r\n\x05\x64\x61tas\x18\x01 \x01(\x0c\x12\x0f\n\x07\x65rrCode\x18\x02 \x01(\x05\x12\x0e\n\x06\x65rrMsg\x18\x03 \x01(\t2@\n\x06HZData\x12\x36\n\x0bHZDataQuery\x12\x11.pb.HZDataRequest\x1a\x12.pb.HZDataResponse\"\x00\x42\x06Z\x04.;pbb\x06proto3'
)




_HZDATAREQUEST = _descriptor.Descriptor(
  name='HZDataRequest',
  full_name='pb.HZDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='methodName', full_name='pb.HZDataRequest.methodName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='params', full_name='pb.HZDataRequest.params', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=20,
  serialized_end=71,
)


_HZDATARESPONSE = _descriptor.Descriptor(
  name='HZDataResponse',
  full_name='pb.HZDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='datas', full_name='pb.HZDataResponse.datas', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errCode', full_name='pb.HZDataResponse.errCode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errMsg', full_name='pb.HZDataResponse.errMsg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=137,
)

DESCRIPTOR.message_types_by_name['HZDataRequest'] = _HZDATAREQUEST
DESCRIPTOR.message_types_by_name['HZDataResponse'] = _HZDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HZDataRequest = _reflection.GeneratedProtocolMessageType('HZDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _HZDATAREQUEST,
  '__module__' : 'hzdata_pb2'
  # @@protoc_insertion_point(class_scope:pb.HZDataRequest)
  })
_sym_db.RegisterMessage(HZDataRequest)

HZDataResponse = _reflection.GeneratedProtocolMessageType('HZDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _HZDATARESPONSE,
  '__module__' : 'hzdata_pb2'
  # @@protoc_insertion_point(class_scope:pb.HZDataResponse)
  })
_sym_db.RegisterMessage(HZDataResponse)


DESCRIPTOR._options = None

_HZDATA = _descriptor.ServiceDescriptor(
  name='HZData',
  full_name='pb.HZData',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=139,
  serialized_end=203,
  methods=[
  _descriptor.MethodDescriptor(
    name='HZDataQuery',
    full_name='pb.HZData.HZDataQuery',
    index=0,
    containing_service=None,
    input_type=_HZDATAREQUEST,
    output_type=_HZDATARESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_HZDATA)

DESCRIPTOR.services_by_name['HZData'] = _HZDATA

# @@protoc_insertion_point(module_scope)
